@@ -91,7 +91,7 @@ class InvoicingVault(InvoicingMixin):
                 self.cert_der = f.read()
         self.cert = crypto.load_certificate(crypto.FILETYPE_PEM, ssl.DER_cert_to_PEM_cert(self.cert_der))
 
-    def generate(self, generation_data, rfc, certify=False):
+    def generate(self, generation_data, rfc, certify=False, permanent_urls=False):
         """Generate XML, Sign it and get SAT stamp
 
         Args:
@@ -141,7 +141,8 @@ class InvoicingVault(InvoicingMixin):
                 'certificate_num': self.certificate_num,
                 'certificate': base64.b64encode(self.cert_der).decode("utf-8"),
                 'signature': base64.b64encode(decoded_signature).decode("utf-8"),
-                'data': g_data
+                'data': g_data,
+                'permanent_urls': permanent_urls
             }
             if certify:
                 r = self._certify_xml(certification_data).json()
@@ -242,7 +243,7 @@ class Invoicing(InvoicingMixin):
         }
         return self._cancel(cd, "/invoicing/cancel/invoice/{}/".format(gid)).json()
 
-    def generate(self, generation_data, certify=False):
+    def generate(self, generation_data, certify=False, permanent_urls=False):
         """Generate XML, Sign it and get SAT stamp
 
         Args:
@@ -276,7 +277,8 @@ class Invoicing(InvoicingMixin):
                 'certificate_num': self.certificate_num,
                 'certificate': base64.b64encode(self.cert_der).decode("utf-8"),
                 'signature': base64.b64encode(signature).decode("utf-8"),
-                'data': g_data
+                'data': g_data,
+                'permanent_urls': permanent_urls
             }
 
             if certify:
